# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.1] - 2023-06-14

### Added

- Added support for composed types serialization.

### Changed

- Changed writer from array to string to prevent writing of multiple values.
- Fixed bug with serializing enums.